DataProcessor
=======================

Many standard electrical calculations. Many of these functions are employed in the :ref:`DataFrame<data_frame>` class.


.. automodule:: DMT.core.data_processor
    :members:
    :undoc-members:
    :show-inheritance:
